Version

Struct Version 

pub struct Version {
    pub version: String,
    pub active: bool,
}

Fields

version: Stringactive: bool

Implementations

Source

impl Version

pub fn init_env(s: &str) -> Result<(), Error>

initializes the environment file.

pub fn list_upstream_go_versions_filter( host: &str, filter: Option<ToolchainFilter>, ) -> Result<Vec<String>, Error>

pub fn list_upstream_go_versions(host: &str) -> Result<Vec<String>, Error>

list upstream go versions if get go version failure from http then fallback use git.

pub fn match_version_req(host: &str, ver_pattern: &str) -> Result<String, Error>

pub fn get_upstream_latest_go_version(host: &str) -> Result<String, Error>

get upstream latest go version.

pub fn list_go_version() -> Result<Vec<Version>, Error>

list locally installed go version.

pub fn set_go_version(version: &str) -> Result<(), Error>

set active go version

pub fn remove_go_version(version: &str) -> Result<(), Error>

remove the go version, if it is current active go version, will ignore deletion.

pub fn remove_go_versions(vers: &[&str]) -> Result<(), Error>

remove multiple go version, if it is current active go version, will ignore deletion.

pub fn current_go_version() -> Result<Option<String>, Error>

current active go version

pub fn list_cache(contain_sha256: Option<bool>) -> Result<Vec<String>, Error>

list ${HOME}/.goup/cache directory items(only file, ignore directory).

pub fn remove_cache() -> Result<(), Error>

remove ${HOME}/.goup/cache directory.

pub fn remove_goup_home() -> Result<(), Error>

remove ${HOME}/.goup directory.

pub fn normalize(ver: &str) -> String

normalize the version string. 1.21.1 -> go1.21.1 go1.21.1 -> go1.21.1 tip -> gotip gotip -> gotip

pub fn semantic(ver: &str) -> Result<SemVersion>

semantic go version string. 1 -> 1.0.0 1.21 -> 1.21.0 1.21rc2 -> 1.21.0-rc2 1.21.1rc2 -> 1.21.1-rc2 1.21-rc2 -> 1.21.0-rc2 1.21.1-rc2 -> 1.21.1-rc2 1.21.1 -> 1.21.1